summaryrefslogtreecommitdiffstats
path: root/korganizer/koeventeditor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/koeventeditor.cpp')
-rw-r--r--korganizer/koeventeditor.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/korganizer/koeventeditor.cpp b/korganizer/koeventeditor.cpp
index 69cb9c76..3373778a 100644
--- a/korganizer/koeventeditor.cpp
+++ b/korganizer/koeventeditor.cpp
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include <tqtooltip.h>
@@ -50,8 +50,8 @@
#include "koeventeditor.h"
-KOEventEditor::KOEventEditor( Calendar *calendar, TQWidget *parent )
- : KOIncidenceEditor( TQString::null, calendar, parent ),
+KOEventEditor::KOEventEditor( Calendar *calendar, TQWidget *tqparent )
+ : KOIncidenceEditor( TQString(), calendar, tqparent ),
mEvent( 0 ), mCalendar( 0 ), mGeneral( 0 ), mRecurrence( 0 ), mFreeBusy( 0 )
{
}
@@ -232,7 +232,7 @@ void KOEventEditor::setTexts( const TQString &summary, const TQString &descripti
{
if ( description.isEmpty() && summary.tqcontains("\n") ) {
mGeneral->setDescription( summary );
- int pos = summary.find( "\n" );
+ int pos = summary.tqfind( "\n" );
mGeneral->setSummary( summary.left( pos ) );
} else {
mGeneral->setSummary( summary );
@@ -307,7 +307,7 @@ bool KOEventEditor::processInput()
mEvent->setOrganizer( Person( KOPrefs::instance()->fullName(),
KOPrefs::instance()->email() ) );
writeEvent( mEvent );
// NOTE: triggered by addIncidence, the kolab resource might open a non-modal dialog (parent is not available in the resource) to select a resource folder. Thus the user can close this dialog before addIncidence() returns.
if ( !mChanger->addIncidence( mEvent, mResource, mSubResource, this ) ) {
delete mEvent;
mEvent = 0;
@@ -307,7 +307,7 @@ bool KOEventEditor::processInput()
KOPrefs::instance()->email() ) );
writeEvent( mEvent );
- // NOTE: triggered by addIncidence, the kolab resource might open a non-modal dialog (parent is not available in the resource) to select a resource folder. Thus the user can close this dialog before addIncidence() returns.
+ // NOTE: triggered by addIncidence, the kolab resource might open a non-modal dialog (tqparent is not available in the resource) to select a resource folder. Thus the user can close this dialog before addIncidence() returns.
if ( !mChanger->addIncidence( mEvent, mResource, mSubResource, this ) ) {
delete mEvent;